from setuptools import setup, find_packages

setup(
    name='Tmsaa7',
    version='0.1.0',
   # description='A small example library',
   # long_description=open('README.md').read(),
   # long_description_content_type='text/markdown',
  #  author='Your Name',
  #  author_email='your.email@example.com',
  #  url='https://github.com/yourusername/my_library',
    packages=find_packages(),
  #  classifiers=[
  #      'Programming Language :: Python :: 3',
  #      'License :: OSI Approved :: MIT License',
  #      'Operating System :: OS Independent',
  #  ],
 #   python_requires='>=3.6',
    install_requires=[],
)
